@@ -48,6 +48,7 @@ using namespace astyle;
 
 // default options:
 ostream *_err = &cerr;
+ostream *_out = &cout;
 string _suffix = ".orig";
 bool _modeManuallySet;
 
@@ -481,184 +482,184 @@ bool stringEndsWith(const string &str, const string &suffix)
 
 void printHelp()
 {
-    (*_err) << endl;
-    (*_err) << "Artistic Style " << _version << "   (http://www.bigfoot.com/~davidsont/astyle)\n";
-    (*_err) << "                       (created by Tal Davidson, davidsont@bigfoot.com)\n";
-    (*_err) << endl;
-    (*_err) << "Usage  :  astyle [options] < Original > Beautified\n";
-    (*_err) << "          astyle [options] Foo.cpp Bar.cpp  [...]\n";
-    (*_err) << endl;
-    (*_err) << "When indenting a specific file, the resulting indented file RETAINS the\n";
-    (*_err) << "original file-name. The original pre-indented file is renamed, with a\n";
-    (*_err) << "suffix of \".orig\" added to the original filename.\n";
-    (*_err) << endl;
-    (*_err) << "By default, astyle is set up to indent C/C++/C# files, with 4 spaces per\n" ;
-    (*_err) << "indent, a maximal indentation of 40 spaces inside continuous statements,\n";
-    (*_err) << "and NO formatting.\n";
-    (*_err) << endl;
-    (*_err) << "Option's Format:\n";
-    (*_err) << "----------------\n";
-    (*_err) << "    Long options (starting with '--') must be written one at a time.\n";
-    (*_err) << "    Short options (starting with '-') may be appended together.\n";
-    (*_err) << "    Thus, -bps4 is the same as -b -p -s4.\n";
-    (*_err) << endl;
-    (*_err) << "Predefined Styling options:\n";
-    (*_err) << "--------------------\n";
-    (*_err) << "    --style=ansi\n";
-    (*_err) << "    ANSI style formatting/indenting.\n";
-    (*_err) << endl;
-    (*_err) << "    --style=kr\n";
-    (*_err) << "    Kernighan&Ritchie style formatting/indenting.\n";
-    (*_err) << endl;
-    (*_err) << "    --style=gnu\n";
-    (*_err) << "    GNU style formatting/indenting.\n";
-    (*_err) << endl;
-    (*_err) << "    --style=java\n";
-    (*_err) << "    Java mode, with standard java style formatting/indenting.\n";
-    (*_err) << endl;
-    (*_err) << "    --style=linux\n";
-    (*_err) << "    Linux mode (i.e. 8 spaces per indent, break definition-block\n";
-    (*_err) << "    brackets but attach command-block brackets.\n";
-    (*_err) << endl;
-    (*_err) << "Indentation options:\n";
-    (*_err) << "--------------------\n";
-    (*_err) << "    -c   OR   --mode=c\n";
-    (*_err) << "    Indent a C, C++ or C# source file (default)\n";
-    (*_err) << endl;
-    (*_err) << "    -j   OR   --mode=java\n";
-    (*_err) << "    Indent a Java(TM) source file\n";
-    (*_err) << endl;
-    (*_err) << "    -s   OR   -s#   OR   --indent=spaces=#\n";
-    (*_err) << "    Indent using # spaces per indent. Not specifying #\n" ;
-    (*_err) << "    will result in a default of 4 spacec per indent.\n" ;
-    (*_err) << endl;
-    (*_err) << "    -t   OR   -t#   OR   --indent=tab=#\n";
-    (*_err) << "    Indent using tab characters, assuming that each\n";
-    (*_err) << "    tab is # spaces long. Not specifying # will result\n";
-    (*_err) << "    in a default assumption of 4 spaces per tab.\n" ;
-    (*_err) << endl;
-    (*_err) << "    -T#   OR   --force-indent=tab=#";
-    (*_err) << "    Indent using tab characters, assuming that each\n";
-    (*_err) << "    tab is # spaces long. Force tabs to be used in areas\n";
-    (*_err) << "    Astyle would prefer to use spaces.\n" ;
-    (*_err) << endl;
-    (*_err) << "    -C   OR   --indent-classes\n";
-    (*_err) << "    Indent 'class' blocks, so that the inner 'public:',\n";
-    (*_err) << "    'protected:' and 'private: headers are indented in\n";
-    (*_err) << "    relation to the class block.\n";
-    (*_err) << endl;
-    (*_err) << "    -S   OR   --indent-switches\n";
-    (*_err) << "    Indent 'switch' blocks, so that the inner 'case XXX:'\n";
-    (*_err) << "    headers are indented in relation to the switch block.\n";
-    (*_err) << endl;
-    (*_err) << "    -K   OR   --indent-cases\n";
-    (*_err) << "    Indent 'case XXX:' lines, so that they are flush with\n";
-    (*_err) << "    their bodies..\n";
-    (*_err) << endl;
-    (*_err) << "    -N   OR   --indent-namespaces\n";
-    (*_err) << "    Indent the contents of namespace blocks.\n";
-    (*_err) << endl;
-    (*_err) << "    -B   OR   --indent-brackets\n";
-    (*_err) << "    Add extra indentation to '{' and '}' block brackets.\n";
-    (*_err) << endl;
-    (*_err) << "    -G   OR   --indent-blocks\n";
-    (*_err) << "    Add extra indentation entire blocks (including brackets).\n";
-    (*_err) << endl;
-    (*_err) << "    -L   OR   --indent-labels\n";
-    (*_err) << "    Indent labels so that they appear one indent less than\n";
-    (*_err) << "    the current indentation level, rather than being\n";
-    (*_err) << "    flushed completely to the left (which is the default).\n";
-    (*_err) << endl;
-    (*_err) << "    -m#  OR  --min-conditional-indent=#\n";
-    (*_err) << "    Indent a minimal # spaces in a continuous conditional\n";
-    (*_err) << "    belonging to a conditional header.\n";
-    (*_err) << endl;
-    (*_err) << "    -M#  OR  --max-instatement-indent=#\n";
-    (*_err) << "    Indent a maximal # spaces in a continuous statement,\n";
-    (*_err) << "    relatively to the previous line.\n";
-    (*_err) << endl;
-    (*_err) << "    -E  OR  --fill-empty-lines\n";
-    (*_err) << "    Fill empty lines with the white space of their\n";
-    (*_err) << "    previous lines.\n";
-    (*_err) << endl;
-    (*_err) << "    --indent-preprocessor\n";
-    (*_err) << "    Indent multi-line #define statements\n";
-    (*_err) << endl;
-    (*_err) << "Formatting options:\n";
-    (*_err) << "-------------------\n";
-    (*_err) << "    -b  OR  --brackets=break\n";
-    (*_err) << "    Break brackets from pre-block code (i.e. ANSI C/C++ style).\n";
-    (*_err) << endl;
-    (*_err) << "    -a  OR  --brackets=attach\n";
-    (*_err) << "    Attach brackets to pre-block code (i.e. Java/K&R style).\n";
-    (*_err) << endl;
-    (*_err) << "    -l  OR  --brackets=linux\n";
-    (*_err) << "    Break definition-block brackets and attach command-block\n";
-    (*_err) << "    brackets.\n";
-    (*_err) << endl;
-    (*_err) << "    --brackets=break-closing-headers\n";
-    (*_err) << "    Break brackets before closing headers (e.g. 'else', 'catch', ..).\n";
-    (*_err) << "    Should be appended to --brackets=attach or --brackets=linux.\n";
-    (*_err) << endl;
-    (*_err) << "    -o   OR  --one-line=keep-statements\n";
-    (*_err) << "    Don't break lines containing multiple statements into\n";
-    (*_err) << "    multiple single-statement lines.\n";
-    (*_err) << endl;
-    (*_err) << "    -O   OR  --one-line=keep-blocks\n";
-    (*_err) << "    Don't break blocks residing completely on one line\n";
-    (*_err) << endl;
-    (*_err) << "    -p   OR  --pad=oper\n";
-    (*_err) << "    Insert space paddings around operators only.\n";
-    (*_err) << endl;
-    (*_err) << "    --pad=paren\n";
-    (*_err) << "    Insert space paddings around parenthesies only.\n";
-    (*_err) << endl;
-    (*_err) << "    -P   OR  --pad=all\n";
-    (*_err) << "    Insert space paddings around operators AND parenthesies.\n";
-    (*_err) << endl;
-    (*_err) << "    --convert-tabs\n";
-    (*_err) << "    Convert tabs to spaces.\n";
-    (*_err) << endl;
-    (*_err) << "    --break-blocks\n";
-    (*_err) << "    Insert empty lines around unrelated blocks, labels, classes, ...\n";
-    (*_err) << endl;
-    (*_err) << "    --break-blocks=all\n";
-    (*_err) << "    Like --break-blocks, except also insert empty lines \n";
-    (*_err) << "    around closing headers (e.g. 'else', 'catch', ...).\n";
-    (*_err) << endl;
-    (*_err) << "    --break-elseifs\n";
-    (*_err) << "    Break 'else if()' statements into two different lines.\n";
-    (*_err) << endl;
-    (*_err) << "Other options:\n";
-    (*_err) << "-------------\n";
-    (*_err) << "    --suffix=####\n";
-    (*_err) << "    Append the suffix #### instead of '.orig' to original filename.\n";
-    (*_err) << endl;
-    (*_err) << "    -X   OR  --errors-to-standard-output\n";
-    (*_err) << "    Print errors and help information to standard-output rather than\n";
-    (*_err) << "    to standard-error.\n";
-    (*_err) << endl;
-    (*_err) << "    -v   OR   --version\n";
-    (*_err) << "    Print version number\n";
-    (*_err) << endl;
-    (*_err) << "    -h   OR   -?   OR   --help\n";
-    (*_err) << "    Print this help message\n";
-    (*_err) << endl;
-    (*_err) << "Default options file:\n";
-    (*_err) << "---------------------\n";
-    (*_err) << "    Artistic Style looks for a default options file in the\n";
-    (*_err) << "    following order:\n";
-    (*_err) << "    1. The contents of the ARTISTIC_STYLE_OPTIONS environment\n";
-    (*_err) << "       variable if it exists.\n";
-    (*_err) << "    2. The file called .astylerc in the directory pointed to by the\n";
-    (*_err) << "       HOME environment variable ( i.e. $HOME/.astylerc ).\n";
-    (*_err) << "    3. The file called .astylerc in the directory pointed to by the\n";
-    (*_err) << "       HOMEPATH environment variable ( i.e. %HOMEPATH%\\.astylerc ).\n";
-    (*_err) << "    If a default options file is found, the options in this file\n";
-    (*_err) << "    will be parsed BEFORE the command-line options.\n";
-    (*_err) << "    Options within the default option file may be written without\n";
-    (*_err) << "    the preliminary '-' or '--'.\n";
-    (*_err) << endl;
+    (*_out) << endl;
+    (*_out) << "Artistic Style " << _version << "   (http://www.bigfoot.com/~davidsont/astyle)\n";
+    (*_out) << "                       (created by Tal Davidson, davidsont@bigfoot.com)\n";
+    (*_out) << endl;
+    (*_out) << "Usage  :  astyle [options] < Original > Beautified\n";
+    (*_out) << "          astyle [options] Foo.cpp Bar.cpp  [...]\n";
+    (*_out) << endl;
+    (*_out) << "When indenting a specific file, the resulting indented file RETAINS the\n";
+    (*_out) << "original file-name. The original pre-indented file is renamed, with a\n";
+    (*_out) << "suffix of \".orig\" added to the original filename.\n";
+    (*_out) << endl;
+    (*_out) << "By default, astyle is set up to indent C/C++/C# files, with 4 spaces per\n" ;
+    (*_out) << "indent, a maximal indentation of 40 spaces inside continuous statements,\n";
+    (*_out) << "and NO formatting.\n";
+    (*_out) << endl;
+    (*_out) << "Option's Format:\n";
+    (*_out) << "----------------\n";
+    (*_out) << "    Long options (starting with '--') must be written one at a time.\n";
+    (*_out) << "    Short options (starting with '-') may be appended together.\n";
+    (*_out) << "    Thus, -bps4 is the same as -b -p -s4.\n";
+    (*_out) << endl;
+    (*_out) << "Predefined Styling options:\n";
+    (*_out) << "--------------------\n";
+    (*_out) << "    --style=ansi\n";
+    (*_out) << "    ANSI style formatting/indenting.\n";
+    (*_out) << endl;
+    (*_out) << "    --style=kr\n";
+    (*_out) << "    Kernighan&Ritchie style formatting/indenting.\n";
+    (*_out) << endl;
+    (*_out) << "    --style=gnu\n";
+    (*_out) << "    GNU style formatting/indenting.\n";
+    (*_out) << endl;
+    (*_out) << "    --style=java\n";
+    (*_out) << "    Java mode, with standard java style formatting/indenting.\n";
+    (*_out) << endl;
+    (*_out) << "    --style=linux\n";
+    (*_out) << "    Linux mode (i.e. 8 spaces per indent, break definition-block\n";
+    (*_out) << "    brackets but attach command-block brackets.\n";
+    (*_out) << endl;
+    (*_out) << "Indentation options:\n";
+    (*_out) << "--------------------\n";
+    (*_out) << "    -c   OR   --mode=c\n";
+    (*_out) << "    Indent a C, C++ or C# source file (default)\n";
+    (*_out) << endl;
+    (*_out) << "    -j   OR   --mode=java\n";
+    (*_out) << "    Indent a Java(TM) source file\n";
+    (*_out) << endl;
+    (*_out) << "    -s   OR   -s#   OR   --indent=spaces=#\n";
+    (*_out) << "    Indent using # spaces per indent. Not specifying #\n" ;
+    (*_out) << "    will result in a default of 4 spacec per indent.\n" ;
+    (*_out) << endl;
+    (*_out) << "    -t   OR   -t#   OR   --indent=tab=#\n";
+    (*_out) << "    Indent using tab characters, assuming that each\n";
+    (*_out) << "    tab is # spaces long. Not specifying # will result\n";
+    (*_out) << "    in a default assumption of 4 spaces per tab.\n" ;
+    (*_out) << endl;
+    (*_out) << "    -T#   OR   --force-indent=tab=#";
+    (*_out) << "    Indent using tab characters, assuming that each\n";
+    (*_out) << "    tab is # spaces long. Force tabs to be used in areas\n";
+    (*_out) << "    Astyle would prefer to use spaces.\n" ;
+    (*_out) << endl;
+    (*_out) << "    -C   OR   --indent-classes\n";
+    (*_out) << "    Indent 'class' blocks, so that the inner 'public:',\n";
+    (*_out) << "    'protected:' and 'private: headers are indented in\n";
+    (*_out) << "    relation to the class block.\n";
+    (*_out) << endl;
+    (*_out) << "    -S   OR   --indent-switches\n";
+    (*_out) << "    Indent 'switch' blocks, so that the inner 'case XXX:'\n";
+    (*_out) << "    headers are indented in relation to the switch block.\n";
+    (*_out) << endl;
+    (*_out) << "    -K   OR   --indent-cases\n";
+    (*_out) << "    Indent 'case XXX:' lines, so that they are flush with\n";
+    (*_out) << "    their bodies..\n";
+    (*_out) << endl;
+    (*_out) << "    -N   OR   --indent-namespaces\n";
+    (*_out) << "    Indent the contents of namespace blocks.\n";
+    (*_out) << endl;
+    (*_out) << "    -B   OR   --indent-brackets\n";
+    (*_out) << "    Add extra indentation to '{' and '}' block brackets.\n";
+    (*_out) << endl;
+    (*_out) << "    -G   OR   --indent-blocks\n";
+    (*_out) << "    Add extra indentation entire blocks (including brackets).\n";
+    (*_out) << endl;
+    (*_out) << "    -L   OR   --indent-labels\n";
+    (*_out) << "    Indent labels so that they appear one indent less than\n";
+    (*_out) << "    the current indentation level, rather than being\n";
+    (*_out) << "    flushed completely to the left (which is the default).\n";
+    (*_out) << endl;
+    (*_out) << "    -m#  OR  --min-conditional-indent=#\n";
+    (*_out) << "    Indent a minimal # spaces in a continuous conditional\n";
+    (*_out) << "    belonging to a conditional header.\n";
+    (*_out) << endl;
+    (*_out) << "    -M#  OR  --max-instatement-indent=#\n";
+    (*_out) << "    Indent a maximal # spaces in a continuous statement,\n";
+    (*_out) << "    relatively to the previous line.\n";
+    (*_out) << endl;
+    (*_out) << "    -E  OR  --fill-empty-lines\n";
+    (*_out) << "    Fill empty lines with the white space of their\n";
+    (*_out) << "    previous lines.\n";
+    (*_out) << endl;
+    (*_out) << "    --indent-preprocessor\n";
+    (*_out) << "    Indent multi-line #define statements\n";
+    (*_out) << endl;
+    (*_out) << "Formatting options:\n";
+    (*_out) << "-------------------\n";
+    (*_out) << "    -b  OR  --brackets=break\n";
+    (*_out) << "    Break brackets from pre-block code (i.e. ANSI C/C++ style).\n";
+    (*_out) << endl;
+    (*_out) << "    -a  OR  --brackets=attach\n";
+    (*_out) << "    Attach brackets to pre-block code (i.e. Java/K&R style).\n";
+    (*_out) << endl;
+    (*_out) << "    -l  OR  --brackets=linux\n";
+    (*_out) << "    Break definition-block brackets and attach command-block\n";
+    (*_out) << "    brackets.\n";
+    (*_out) << endl;
+    (*_out) << "    --brackets=break-closing-headers\n";
+    (*_out) << "    Break brackets before closing headers (e.g. 'else', 'catch', ..).\n";
+    (*_out) << "    Should be appended to --brackets=attach or --brackets=linux.\n";
+    (*_out) << endl;
+    (*_out) << "    -o   OR  --one-line=keep-statements\n";
+    (*_out) << "    Don't break lines containing multiple statements into\n";
+    (*_out) << "    multiple single-statement lines.\n";
+    (*_out) << endl;
+    (*_out) << "    -O   OR  --one-line=keep-blocks\n";
+    (*_out) << "    Don't break blocks residing completely on one line\n";
+    (*_out) << endl;
+    (*_out) << "    -p   OR  --pad=oper\n";
+    (*_out) << "    Insert space paddings around operators only.\n";
+    (*_out) << endl;
+    (*_out) << "    --pad=paren\n";
+    (*_out) << "    Insert space paddings around parenthesies only.\n";
+    (*_out) << endl;
+    (*_out) << "    -P   OR  --pad=all\n";
+    (*_out) << "    Insert space paddings around operators AND parenthesies.\n";
+    (*_out) << endl;
+    (*_out) << "    --convert-tabs\n";
+    (*_out) << "    Convert tabs to spaces.\n";
+    (*_out) << endl;
+    (*_out) << "    --break-blocks\n";
+    (*_out) << "    Insert empty lines around unrelated blocks, labels, classes, ...\n";
+    (*_out) << endl;
+    (*_out) << "    --break-blocks=all\n";
+    (*_out) << "    Like --break-blocks, except also insert empty lines \n";
+    (*_out) << "    around closing headers (e.g. 'else', 'catch', ...).\n";
+    (*_out) << endl;
+    (*_out) << "    --break-elseifs\n";
+    (*_out) << "    Break 'else if()' statements into two different lines.\n";
+    (*_out) << endl;
+    (*_out) << "Other options:\n";
+    (*_out) << "-------------\n";
+    (*_out) << "    --suffix=####\n";
+    (*_out) << "    Append the suffix #### instead of '.orig' to original filename.\n";
+    (*_out) << endl;
+    (*_out) << "    -X   OR  --errors-to-standard-output\n";
+    (*_out) << "    Print errors and help information to standard-output rather than\n";
+    (*_out) << "    to standard-error.\n";
+    (*_out) << endl;
+    (*_out) << "    -v   OR   --version\n";
+    (*_out) << "    Print version number\n";
+    (*_out) << endl;
+    (*_out) << "    -h   OR   -?   OR   --help\n";
+    (*_out) << "    Print this help message\n";
+    (*_out) << endl;
+    (*_out) << "Default options file:\n";
+    (*_out) << "---------------------\n";
+    (*_out) << "    Artistic Style looks for a default options file in the\n";
+    (*_out) << "    following order:\n";
+    (*_out) << "    1. The contents of the ARTISTIC_STYLE_OPTIONS environment\n";
+    (*_out) << "       variable if it exists.\n";
+    (*_out) << "    2. The file called .astylerc in the directory pointed to by the\n";
+    (*_out) << "       HOME environment variable ( i.e. $HOME/.astylerc ).\n";
+    (*_out) << "    3. The file called .astylerc in the directory pointed to by the\n";
+    (*_out) << "       HOMEPATH environment variable ( i.e. %HOMEPATH%\\.astylerc ).\n";
+    (*_out) << "    If a default options file is found, the options in this file\n";
+    (*_out) << "    will be parsed BEFORE the command-line options.\n";
+    (*_out) << "    Options within the default option file may be written without\n";
+    (*_out) << "    the preliminary '-' or '--'.\n";
+    (*_out) << endl;
 }
 
 int main(int argc, char *argv[])
